local addonName = "BiggerFishToFryTracker"
local version = "1.3.0"

local bfft = CreateFrame("Frame","BiggerFishToFryTracker",UIParent,"BasicFrameTemplateWithInset")
bfft.achievementId = 10596

bfft.zone_Azsuna = { 8, 11, 6 }
bfft.zone_ValSharah = { 3, 17, 18}
bfft.zone_HighMountain = { 2, 5, 10}
bfft.zone_Stormheim = { 12, 15, 7}
bfft.zone_Ocean = { 13, 4, 1}
bfft.zone_Suramar = { 9, 14, 16}

bfft.lures = 
{
    [8] = "Skrog Toenail -> attacked by Murloc -> Aromatic Murloc Slime",
    [11] = "Pearlescent Conch",
    [6] = "Rusty Queenfish Brooch -> see Ghostly Queenfish Pools",
    [3] = "Rotten Fishbone",
    [18] = "Drowned Thistleleaf",
    [17] = "Nightmare Nightcrawler",
    [10] = "Swollen Murloc Egg -> dancing baby murloc",
    [2] = "Funky Sea Snail -> attacked by Drogbar -> Salmon Lure",
    [5] = "Frost Worm",
    [12] = "Ancient Vrykul Ring -> see Oodelfjlisken schools",
    [15] = "Moosehorn Hook -> fish up Silverscale Minnow (bait)",
    [7] = "Soggy Drakescale",
    [13] = "Stunned, Angry Shark -> use quickly or it disappears !!! -> kill shark (beware mouth)",
    [4] = "Message in a Beer Bottle -> Axefish Lure",
	[1] = "Decayed Whale Blubber -> click on fly -> Ravenous Fly (bait)",
    [9] = "Enchanted Lure",
    [14] = "Demonic Detritus",
	[16] = "Sleeping Murloc -> murloc runs away (run over the fish he drops)",
}

local function PrintResults (name, completed, criteria, lures)
    local completedFish

    if not completed then
        completedFish = 0
    else
        completedFish = 1
    end

	if ((not completed) or lures) then
		print (string.format ("    %s ( %s )", name, bfft.lures[criteria]))
	end
    return completedFish
end

local function ReportFishZone(zoneName, criteriaList, lures)

    local completedFish = 0
    for elementCount=1, #criteriaList do
        local name, _, completed = GetAchievementCriteriaInfo (bfft.achievementId, criteriaList[elementCount])
        completedFish = completedFish + PrintResults (name, completed, criteriaList[elementCount], lures)
    end
    if (completedFish == 3) then
        print ("    Zone Complete");
    end

end

local function StripString(pattern)

    local patternBare = string.gsub (pattern, " ", "")
    patternBare = string.gsub (patternBare, "'", "")
    patternBare = string.lower (patternBare)

	return patternBare

end

local function ReportSingleZoneIfMatch(pattern, superString, fishList, lures)

    local patternBare = StripString (pattern)
    local superStringBare = StripString(superString)

    if (string.find (superStringBare, patternBare) ~= nil) then
        print (" ")
        print (string.format ("Rare fish in %s", superString))
        ReportFishZone (superString, fishList, lures)
    end
end

local function ShowLures (message)
	
    if (string.find (message, "lures") == nil) then
        return false
    else
		return true
    end
end

local function ReportRareFish (msg, editbox)

    local showLures = ShowLures(msg)
    local zone = string.gsub(msg, "lures", "")

    print (string.format ("Bigger Fish to Fry Tracker v %s", version))
    print ("Based on the wowhead guide 'The Underlight Angler - A Step by Step Guide to Obtaining Legion's Fishing Artifact' by madseasonshow")
    print (string.format ("Request rare fish not yet caught in zone(s) matching:  %s", zone))
    print (string.format ("Showing all lures: %s", tostring(showLures)))

    zone = StripString(zone)
    if (string.lower (zone) == "local" or string.lower (zone) == "this") then
		zone = GetZoneText()
    end

    if (zone == "all") then
		zone = ""
	end

	if (zone ~= "?") then

		ReportSingleZoneIfMatch (zone, "Azsuna", bfft.zone_Azsuna, showLures)
        ReportSingleZoneIfMatch (zone, "Val'Sharah", bfft.zone_ValSharah, showLures)
        ReportSingleZoneIfMatch (zone, "Highmountain", bfft.zone_HighMountain, showLures)
        ReportSingleZoneIfMatch (zone, "Stormheim", bfft.zone_Stormheim, showLures)
        ReportSingleZoneIfMatch (zone, "Ocean", bfft.zone_Ocean, showLures)
        ReportSingleZoneIfMatch (zone, "Suramar", bfft.zone_Suramar, showLures)

    else

        print ("Usage:  ")
        print ("/bfft  or  /bfft all  - gives a summary of all zones")
        print ("/bfft <any part of the zone name> - gives results for all zones which match eg. /bfft val")
        print ("/bfft this - results for the zone you are currently in (if any)")
        print ("/bfft <zone> lures - shows lures for requested zone (named/all/this)")

    end
    print (" ")

end

-- slash handler (/bfft)
SLASH_BFFT1 = "/bfft"
SlashCmdList["BFFT"] = ReportRareFish
